@@ -28,7 +28,7 @@ public:
 
 	~CommentsForm();
 
-public slots:
+public Q_SLOTS:
 	void ok();
 	void cancel();
 };
